var __create = Object.create;
var __defProp = Object.defineProperty;
var __getProtoOf = Object.getPrototypeOf;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __toESM = (mod, isNodeMode, target) => {
  target = mod != null ? __create(__getProtoOf(mod)) : {};
  const to = isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target;
  for (let key of __getOwnPropNames(mod))
    if (!__hasOwnProp.call(to, key))
      __defProp(to, key, {
        get: () => mod[key],
        enumerable: true
      });
  return to;
};
var __commonJS = (cb, mod) => () => (mod || cb((mod = { exports: {} }).exports, mod), mod.exports);

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/Slice.js
var require_Slice = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.Slice = undefined;

  class Slice {
    constructor(uint8, view, start, end) {
      this.uint8 = uint8;
      this.view = view;
      this.start = start;
      this.end = end;
    }
    subarray() {
      return this.uint8.subarray(this.start, this.end);
    }
  }
  exports.Slice = Slice;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/Writer.js
var require_Writer = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.Writer = undefined;
  var Slice_1 = require_Slice();
  var EMPTY_UINT8 = new Uint8Array([]);
  var EMPTY_VIEW = new DataView(EMPTY_UINT8.buffer);
  var hasBuffer = typeof Buffer === "function";
  var utf8Write = hasBuffer ? Buffer.prototype.utf8Write : null;
  var from = hasBuffer ? Buffer.from : null;
  var textEncoder = typeof TextEncoder !== "undefined" ? new TextEncoder : null;

  class Writer {
    constructor(allocSize = 64 * 1024) {
      this.allocSize = allocSize;
      this.view = EMPTY_VIEW;
      this.x0 = 0;
      this.x = 0;
      this.uint8 = new Uint8Array(allocSize);
      this.size = allocSize;
      this.view = new DataView(this.uint8.buffer);
    }
    grow(size) {
      const x0 = this.x0;
      const x = this.x;
      const oldUint8 = this.uint8;
      const newUint8 = new Uint8Array(size);
      const view = new DataView(newUint8.buffer);
      const activeSlice = oldUint8.subarray(x0, x);
      newUint8.set(activeSlice, 0);
      this.x = x - x0;
      this.x0 = 0;
      this.uint8 = newUint8;
      this.size = size;
      this.view = view;
    }
    ensureCapacity(capacity) {
      const byteLength = this.size;
      const remaining = byteLength - this.x;
      if (remaining < capacity) {
        const total = byteLength - this.x0;
        const required = capacity - remaining;
        const totalRequired = total + required;
        this.grow(totalRequired <= this.allocSize ? this.allocSize : totalRequired * 2);
      }
    }
    move(capacity) {
      this.ensureCapacity(capacity);
      this.x += capacity;
    }
    reset() {
      this.x0 = this.x;
    }
    newBuffer(size) {
      const uint8 = this.uint8 = new Uint8Array(size);
      this.size = size;
      this.view = new DataView(uint8.buffer);
      this.x = this.x0 = 0;
    }
    flush() {
      const result = this.uint8.subarray(this.x0, this.x);
      this.x0 = this.x;
      return result;
    }
    flushSlice() {
      const slice = new Slice_1.Slice(this.uint8, this.view, this.x0, this.x);
      this.x0 = this.x;
      return slice;
    }
    u8(char) {
      this.ensureCapacity(1);
      this.uint8[this.x++] = char;
    }
    u16(word) {
      this.ensureCapacity(2);
      this.view.setUint16(this.x, word);
      this.x += 2;
    }
    u32(dword) {
      this.ensureCapacity(4);
      this.view.setUint32(this.x, dword);
      this.x += 4;
    }
    i32(dword) {
      this.ensureCapacity(4);
      this.view.setInt32(this.x, dword);
      this.x += 4;
    }
    u64(qword) {
      this.ensureCapacity(8);
      this.view.setBigUint64(this.x, BigInt(qword));
      this.x += 8;
    }
    f64(float) {
      this.ensureCapacity(8);
      this.view.setFloat64(this.x, float);
      this.x += 8;
    }
    u8u16(u8, u16) {
      this.ensureCapacity(3);
      let x = this.x;
      this.uint8[x++] = u8;
      this.uint8[x++] = u16 >>> 8;
      this.uint8[x++] = u16 & 255;
      this.x = x;
    }
    u8u32(u8, u32) {
      this.ensureCapacity(5);
      let x = this.x;
      this.uint8[x++] = u8;
      this.view.setUint32(x, u32);
      this.x = x + 4;
    }
    u8u64(u8, u64) {
      this.ensureCapacity(9);
      let x = this.x;
      this.uint8[x++] = u8;
      this.view.setBigUint64(x, BigInt(u64));
      this.x = x + 8;
    }
    u8f32(u8, f32) {
      this.ensureCapacity(5);
      let x = this.x;
      this.uint8[x++] = u8;
      this.view.setFloat32(x, f32);
      this.x = x + 4;
    }
    u8f64(u8, f64) {
      this.ensureCapacity(9);
      let x = this.x;
      this.uint8[x++] = u8;
      this.view.setFloat64(x, f64);
      this.x = x + 8;
    }
    buf(buf, length) {
      this.ensureCapacity(length);
      const x = this.x;
      this.uint8.set(buf, x);
      this.x = x + length;
    }
    utf8(str) {
      const maxLength = str.length * 4;
      if (maxLength < 168)
        return this.utf8Native(str);
      if (utf8Write) {
        const writeLength = utf8Write.call(this.uint8, str, this.x, maxLength);
        this.x += writeLength;
        return writeLength;
      } else if (from) {
        const uint8 = this.uint8;
        const offset = uint8.byteOffset + this.x;
        const buf = from(uint8.buffer).subarray(offset, offset + maxLength);
        const writeLength = buf.write(str, 0, maxLength, "utf8");
        this.x += writeLength;
        return writeLength;
      } else if (maxLength > 1024 && textEncoder) {
        const writeLength = textEncoder.encodeInto(str, this.uint8.subarray(this.x, this.x + maxLength)).written;
        this.x += writeLength;
        return writeLength;
      }
      return this.utf8Native(str);
    }
    utf8Native(str) {
      const length = str.length;
      const uint8 = this.uint8;
      let offset = this.x;
      let pos = 0;
      while (pos < length) {
        let value = str.charCodeAt(pos++);
        if ((value & 4294967168) === 0) {
          uint8[offset++] = value;
          continue;
        } else if ((value & 4294965248) === 0) {
          uint8[offset++] = value >> 6 & 31 | 192;
        } else {
          if (value >= 55296 && value <= 56319) {
            if (pos < length) {
              const extra = str.charCodeAt(pos);
              if ((extra & 64512) === 56320) {
                pos++;
                value = ((value & 1023) << 10) + (extra & 1023) + 65536;
              }
            }
          }
          if ((value & 4294901760) === 0) {
            uint8[offset++] = value >> 12 & 15 | 224;
            uint8[offset++] = value >> 6 & 63 | 128;
          } else {
            uint8[offset++] = value >> 18 & 7 | 240;
            uint8[offset++] = value >> 12 & 63 | 128;
            uint8[offset++] = value >> 6 & 63 | 128;
          }
        }
        uint8[offset++] = value & 63 | 128;
      }
      const writeLength = offset - this.x;
      this.x = offset;
      return writeLength;
    }
    ascii(str) {
      const length = str.length;
      this.ensureCapacity(length);
      const uint8 = this.uint8;
      let x = this.x;
      let pos = 0;
      while (pos < length)
        uint8[x++] = str.charCodeAt(pos++);
      this.x = x;
    }
  }
  exports.Writer = Writer;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/json-pack/lib/msgpack/MsgPackEncoderFast.js
var require_MsgPackEncoderFast = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.MsgPackEncoderFast = undefined;
  var Writer_1 = require_Writer();

  class MsgPackEncoderFast {
    constructor(writer = new Writer_1.Writer) {
      this.writer = writer;
    }
    encode(json) {
      this.writer.reset();
      this.writeAny(json);
      return this.writer.flush();
    }
    encodeAny(json) {
      this.writeAny(json);
    }
    writeAny(value) {
      switch (value) {
        case null:
          return this.writer.u8(192);
        case false:
          return this.writer.u8(194);
        case true:
          return this.writer.u8(195);
      }
      if (value instanceof Array)
        return this.writeArr(value);
      switch (typeof value) {
        case "number":
          return this.writeNumber(value);
        case "string":
          return this.writeStr(value);
        case "object":
          return this.writeObj(value);
      }
    }
    encodeFloat64(num) {
      this.writeFloat(num);
    }
    writeNull() {
      return this.writer.u8(192);
    }
    writeFloat(float) {
      this.writer.u8f64(203, float);
    }
    u32(num) {
      const writer = this.writer;
      this.writer.ensureCapacity(5);
      const uint8 = writer.uint8;
      if (num <= 127) {
        uint8[writer.x++] = num;
      } else if (num <= 65535) {
        uint8[writer.x++] = 205;
        writer.view.setUint16(writer.x, num);
        writer.x += 2;
      } else if (num <= 4294967295) {
        uint8[writer.x++] = 206;
        writer.view.setUint32(writer.x, num);
        writer.x += 4;
      } else
        this.writeFloat(num);
    }
    n32(num) {
      const writer = this.writer;
      this.writer.ensureCapacity(5);
      const uint8 = writer.uint8;
      if (num >= -32) {
        uint8[writer.x++] = 256 + num;
      } else if (num >= -32768) {
        uint8[writer.x++] = 209;
        writer.view.setInt16(writer.x, num);
        writer.x += 2;
      } else if (num >= -2147483648) {
        uint8[writer.x++] = 210;
        writer.view.setInt32(writer.x, num);
        writer.x += 4;
      } else
        this.writeFloat(num);
    }
    encodeNumber(num) {
      this.writeNumber(num);
    }
    writeNumber(num) {
      if (num >>> 0 === num)
        return this.u32(num);
      if (num >> 0 === num)
        return this.n32(num);
      this.writeFloat(num);
    }
    writeInteger(int) {
      if (int >= 0) {
        if (int <= 4294967295)
          return this.u32(int);
        else if (int > -2147483648)
          return this.n32(int);
      }
      this.writeFloat(int);
    }
    writeUInteger(uint) {
      if (uint <= 4294967295)
        return this.u32(uint);
      this.writeFloat(uint);
    }
    encodeNull() {
      this.writer.u8(192);
    }
    encodeTrue() {
      this.writer.u8(195);
    }
    encodeFalse() {
      this.writer.u8(194);
    }
    encodeBoolean(bool) {
      this.writeBoolean(bool);
    }
    writeBoolean(bool) {
      if (bool)
        this.writer.u8(195);
      else
        this.writer.u8(194);
    }
    encodeStringHeader(length) {
      this.writeStrHdr(length);
    }
    writeStrHdr(length) {
      if (length <= 31)
        this.writer.u8(160 | length);
      else if (length <= 255)
        this.writer.u16(55552 + length);
      else if (length <= 65535)
        this.writer.u8u16(218, length);
      else
        this.writer.u8u32(219, length);
    }
    encodeString(str) {
      this.writeStr(str);
    }
    writeStr(str) {
      const writer = this.writer;
      const length = str.length;
      const maxSize = length * 4;
      writer.ensureCapacity(5 + maxSize);
      const uint8 = writer.uint8;
      let lengthOffset = writer.x;
      if (maxSize <= 31)
        writer.x++;
      else if (maxSize <= 255) {
        uint8[writer.x++] = 217;
        lengthOffset = writer.x;
        writer.x++;
      } else if (maxSize <= 65535) {
        uint8[writer.x++] = 218;
        lengthOffset = writer.x;
        writer.x += 2;
      } else {
        uint8[writer.x++] = 219;
        lengthOffset = writer.x;
        writer.x += 4;
      }
      const bytesWritten = this.writer.utf8(str);
      if (maxSize <= 31)
        uint8[lengthOffset] = 160 | bytesWritten;
      else if (maxSize <= 255)
        uint8[lengthOffset] = bytesWritten;
      else if (maxSize <= 65535)
        writer.view.setUint16(lengthOffset, bytesWritten);
      else
        writer.view.setUint32(lengthOffset, bytesWritten);
    }
    encodeAsciiString(str) {
      this.writeAsciiStr(str);
    }
    writeAsciiStr(str) {
      this.writeStrHdr(str.length);
      this.writer.ascii(str);
    }
    encodeArrayHeader(length) {
      this.writeArrHdr(length);
    }
    encodeArray(arr) {
      this.writeArr(arr);
    }
    writeArrHdr(length) {
      if (length <= 15)
        this.writer.u8(144 | length);
      else if (length <= 65535)
        this.writer.u8u16(220, length);
      else if (length <= 4294967295)
        this.writer.u8u32(221, length);
    }
    writeArr(arr) {
      const length = arr.length;
      if (length <= 15)
        this.writer.u8(144 | length);
      else if (length <= 65535)
        this.writer.u8u16(220, length);
      else if (length <= 4294967295)
        this.writer.u8u32(221, length);
      for (let i = 0;i < length; i++)
        this.writeAny(arr[i]);
    }
    encodeObjectHeader(length) {
      this.writeObjHdr(length);
    }
    encodeObject(obj) {
      this.writeObj(obj);
    }
    writeObjHdr(length) {
      if (length <= 15)
        this.writer.u8(128 | length);
      else if (length <= 65535) {
        this.writer.u8u16(222, length);
      } else if (length <= 4294967295) {
        this.writer.u8u32(223, length);
      }
    }
    writeObj(obj) {
      const keys = Object.keys(obj);
      const length = keys.length;
      this.writeObjHdr(length);
      for (let i = 0;i < length; i++) {
        const key = keys[i];
        this.writeStr(key);
        this.writeAny(obj[key]);
      }
    }
    encodeExtHeader(type, length) {
      switch (length) {
        case 1:
          this.writer.u16(212 << 8 | type);
          break;
        case 2:
          this.writer.u16(213 << 8 | type);
          break;
        case 4:
          this.writer.u16(214 << 8 | type);
          break;
        case 8:
          this.writer.u16(215 << 8 | type);
          break;
        case 16:
          this.writer.u16(216 << 8 | type);
          break;
        default:
          if (length <= 255) {
            this.writer.u16(199 << 8 | length);
            this.writer.u8(type);
          } else if (length <= 65535) {
            this.writer.u8u16(200, length);
            this.writer.u8(type);
          } else if (length <= 4294967295) {
            this.writer.u8u32(201, length);
            this.writer.u8(type);
          }
      }
    }
    encodeExt(ext) {
      const { tag: type, val: buf } = ext;
      const length = buf.length;
      this.encodeExtHeader(type, length);
      this.writer.buf(buf, length);
    }
    encodeBinaryHeader(length) {
      this.writeBinHdr(length);
    }
    encodeBinary(buf) {
      this.writeBin(buf);
    }
    writeBinHdr(length) {
      if (length <= 255)
        this.writer.u16(196 << 8 | length);
      else if (length <= 65535) {
        this.writer.u8u16(197, length);
      } else if (length <= 4294967295) {
        this.writer.u8u32(198, length);
      }
    }
    writeBin(buf) {
      const length = buf.length;
      this.writeBinHdr(length);
      this.writer.buf(buf, length);
    }
  }
  exports.MsgPackEncoderFast = MsgPackEncoderFast;
});

// /Users/jpsilva/Projects/integro/node_modules/tslib/tslib.js
var require_tslib = __commonJS((exports, module) => {
  var __extends;
  var __assign;
  var __rest;
  var __decorate;
  var __param;
  var __esDecorate;
  var __runInitializers;
  var __propKey;
  var __setFunctionName;
  var __metadata;
  var __awaiter;
  var __generator;
  var __exportStar;
  var __values;
  var __read;
  var __spread;
  var __spreadArrays;
  var __spreadArray;
  var __await;
  var __asyncGenerator;
  var __asyncDelegator;
  var __asyncValues;
  var __makeTemplateObject;
  var __importStar;
  var __importDefault;
  var __classPrivateFieldGet;
  var __classPrivateFieldSet;
  var __classPrivateFieldIn;
  var __createBinding;
  var __addDisposableResource;
  var __disposeResources;
  (function(factory) {
    var root = typeof global === "object" ? global : typeof self === "object" ? self : typeof this === "object" ? this : {};
    if (typeof define === "function" && define.amd) {
      define("tslib", ["exports"], function(exports2) {
        factory(createExporter(root, createExporter(exports2)));
      });
    } else if (typeof module === "object" && typeof exports === "object") {
      factory(createExporter(root, createExporter(exports)));
    } else {
      factory(createExporter(root));
    }
    function createExporter(exports2, previous) {
      if (exports2 !== root) {
        if (typeof Object.create === "function") {
          Object.defineProperty(exports2, "__esModule", { value: true });
        } else {
          exports2.__esModule = true;
        }
      }
      return function(id, v) {
        return exports2[id] = previous ? previous(id, v) : v;
      };
    }
  })(function(exporter) {
    var extendStatics = Object.setPrototypeOf || { __proto__: [] } instanceof Array && function(d, b) {
      d.__proto__ = b;
    } || function(d, b) {
      for (var p in b)
        if (Object.prototype.hasOwnProperty.call(b, p))
          d[p] = b[p];
    };
    __extends = function(d, b) {
      if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
      extendStatics(d, b);
      function __() {
        this.constructor = d;
      }
      d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __);
    };
    __assign = Object.assign || function(t) {
      for (var s, i = 1, n = arguments.length;i < n; i++) {
        s = arguments[i];
        for (var p in s)
          if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
      }
      return t;
    };
    __rest = function(s, e) {
      var t = {};
      for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
          t[p] = s[p];
      if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s);i < p.length; i++) {
          if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
            t[p[i]] = s[p[i]];
        }
      return t;
    };
    __decorate = function(decorators, target, key, desc) {
      var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
      if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
        r = Reflect.decorate(decorators, target, key, desc);
      else
        for (var i = decorators.length - 1;i >= 0; i--)
          if (d = decorators[i])
            r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
      return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    __param = function(paramIndex, decorator) {
      return function(target, key) {
        decorator(target, key, paramIndex);
      };
    };
    __esDecorate = function(ctor, descriptorIn, decorators, contextIn, initializers, extraInitializers) {
      function accept(f) {
        if (f !== undefined && typeof f !== "function")
          throw new TypeError("Function expected");
        return f;
      }
      var kind = contextIn.kind, key = kind === "getter" ? "get" : kind === "setter" ? "set" : "value";
      var target = !descriptorIn && ctor ? contextIn["static"] ? ctor : ctor.prototype : null;
      var descriptor = descriptorIn || (target ? Object.getOwnPropertyDescriptor(target, contextIn.name) : {});
      var _, done = false;
      for (var i = decorators.length - 1;i >= 0; i--) {
        var context = {};
        for (var p in contextIn)
          context[p] = p === "access" ? {} : contextIn[p];
        for (var p in contextIn.access)
          context.access[p] = contextIn.access[p];
        context.addInitializer = function(f) {
          if (done)
            throw new TypeError("Cannot add initializers after decoration has completed");
          extraInitializers.push(accept(f || null));
        };
        var result = (0, decorators[i])(kind === "accessor" ? { get: descriptor.get, set: descriptor.set } : descriptor[key], context);
        if (kind === "accessor") {
          if (result === undefined)
            continue;
          if (result === null || typeof result !== "object")
            throw new TypeError("Object expected");
          if (_ = accept(result.get))
            descriptor.get = _;
          if (_ = accept(result.set))
            descriptor.set = _;
          if (_ = accept(result.init))
            initializers.unshift(_);
        } else if (_ = accept(result)) {
          if (kind === "field")
            initializers.unshift(_);
          else
            descriptor[key] = _;
        }
      }
      if (target)
        Object.defineProperty(target, contextIn.name, descriptor);
      done = true;
    };
    __runInitializers = function(thisArg, initializers, value) {
      var useValue = arguments.length > 2;
      for (var i = 0;i < initializers.length; i++) {
        value = useValue ? initializers[i].call(thisArg, value) : initializers[i].call(thisArg);
      }
      return useValue ? value : undefined;
    };
    __propKey = function(x) {
      return typeof x === "symbol" ? x : "".concat(x);
    };
    __setFunctionName = function(f, name, prefix) {
      if (typeof name === "symbol")
        name = name.description ? "[".concat(name.description, "]") : "";
      return Object.defineProperty(f, "name", { configurable: true, value: prefix ? "".concat(prefix, " ", name) : name });
    };
    __metadata = function(metadataKey, metadataValue) {
      if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
        return Reflect.metadata(metadataKey, metadataValue);
    };
    __awaiter = function(thisArg, _arguments, P, generator) {
      function adopt(value) {
        return value instanceof P ? value : new P(function(resolve) {
          resolve(value);
        });
      }
      return new (P || (P = Promise))(function(resolve, reject) {
        function fulfilled(value) {
          try {
            step(generator.next(value));
          } catch (e) {
            reject(e);
          }
        }
        function rejected(value) {
          try {
            step(generator["throw"](value));
          } catch (e) {
            reject(e);
          }
        }
        function step(result) {
          result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
      });
    };
    __generator = function(thisArg, body) {
      var _ = { label: 0, sent: function() {
        if (t[0] & 1)
          throw t[1];
        return t[1];
      }, trys: [], ops: [] }, f, y, t, g;
      return g = { next: verb(0), throw: verb(1), return: verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() {
        return this;
      }), g;
      function verb(n) {
        return function(v) {
          return step([n, v]);
        };
      }
      function step(op) {
        if (f)
          throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _)
          try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
              return t;
            if (y = 0, t)
              op = [op[0] & 2, t.value];
            switch (op[0]) {
              case 0:
              case 1:
                t = op;
                break;
              case 4:
                _.label++;
                return { value: op[1], done: false };
              case 5:
                _.label++;
                y = op[1];
                op = [0];
                continue;
              case 7:
                op = _.ops.pop();
                _.trys.pop();
                continue;
              default:
                if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                  _ = 0;
                  continue;
                }
                if (op[0] === 3 && (!t || op[1] > t[0] && op[1] < t[3])) {
                  _.label = op[1];
                  break;
                }
                if (op[0] === 6 && _.label < t[1]) {
                  _.label = t[1];
                  t = op;
                  break;
                }
                if (t && _.label < t[2]) {
                  _.label = t[2];
                  _.ops.push(op);
                  break;
                }
                if (t[2])
                  _.ops.pop();
                _.trys.pop();
                continue;
            }
            op = body.call(thisArg, _);
          } catch (e) {
            op = [6, e];
            y = 0;
          } finally {
            f = t = 0;
          }
        if (op[0] & 5)
          throw op[1];
        return { value: op[0] ? op[1] : undefined, done: true };
      }
    };
    __exportStar = function(m, o) {
      for (var p in m)
        if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
          __createBinding(o, m, p);
    };
    __createBinding = Object.create ? function(o, m, k, k2) {
      if (k2 === undefined)
        k2 = k;
      var desc = Object.getOwnPropertyDescriptor(m, k);
      if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
        desc = { enumerable: true, get: function() {
          return m[k];
        } };
      }
      Object.defineProperty(o, k2, desc);
    } : function(o, m, k, k2) {
      if (k2 === undefined)
        k2 = k;
      o[k2] = m[k];
    };
    __values = function(o) {
      var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
      if (m)
        return m.call(o);
      if (o && typeof o.length === "number")
        return {
          next: function() {
            if (o && i >= o.length)
              o = undefined;
            return { value: o && o[i++], done: !o };
          }
        };
      throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    };
    __read = function(o, n) {
      var m = typeof Symbol === "function" && o[Symbol.iterator];
      if (!m)
        return o;
      var i = m.call(o), r, ar = [], e;
      try {
        while ((n === undefined || n-- > 0) && !(r = i.next()).done)
          ar.push(r.value);
      } catch (error) {
        e = { error };
      } finally {
        try {
          if (r && !r.done && (m = i["return"]))
            m.call(i);
        } finally {
          if (e)
            throw e.error;
        }
      }
      return ar;
    };
    __spread = function() {
      for (var ar = [], i = 0;i < arguments.length; i++)
        ar = ar.concat(__read(arguments[i]));
      return ar;
    };
    __spreadArrays = function() {
      for (var s = 0, i = 0, il = arguments.length;i < il; i++)
        s += arguments[i].length;
      for (var r = Array(s), k = 0, i = 0;i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length;j < jl; j++, k++)
          r[k] = a[j];
      return r;
    };
    __spreadArray = function(to, from, pack) {
      if (pack || arguments.length === 2)
        for (var i = 0, l = from.length, ar;i < l; i++) {
          if (ar || !(i in from)) {
            if (!ar)
              ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
          }
        }
      return to.concat(ar || Array.prototype.slice.call(from));
    };
    __await = function(v) {
      return this instanceof __await ? (this.v = v, this) : new __await(v);
    };
    __asyncGenerator = function(thisArg, _arguments, generator) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var g = generator.apply(thisArg, _arguments || []), i, q = [];
      return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i;
      function verb(n) {
        if (g[n])
          i[n] = function(v) {
            return new Promise(function(a, b) {
              q.push([n, v, a, b]) > 1 || resume(n, v);
            });
          };
      }
      function resume(n, v) {
        try {
          step(g[n](v));
        } catch (e) {
          settle(q[0][3], e);
        }
      }
      function step(r) {
        r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r);
      }
      function fulfill(value) {
        resume("next", value);
      }
      function reject(value) {
        resume("throw", value);
      }
      function settle(f, v) {
        if (f(v), q.shift(), q.length)
          resume(q[0][0], q[0][1]);
      }
    };
    __asyncDelegator = function(o) {
      var i, p;
      return i = {}, verb("next"), verb("throw", function(e) {
        throw e;
      }), verb("return"), i[Symbol.iterator] = function() {
        return this;
      }, i;
      function verb(n, f) {
        i[n] = o[n] ? function(v) {
          return (p = !p) ? { value: __await(o[n](v)), done: false } : f ? f(v) : v;
        } : f;
      }
    };
    __asyncValues = function(o) {
      if (!Symbol.asyncIterator)
        throw new TypeError("Symbol.asyncIterator is not defined.");
      var m = o[Symbol.asyncIterator], i;
      return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function() {
        return this;
      }, i);
      function verb(n) {
        i[n] = o[n] && function(v) {
          return new Promise(function(resolve, reject) {
            v = o[n](v), settle(resolve, reject, v.done, v.value);
          });
        };
      }
      function settle(resolve, reject, d, v) {
        Promise.resolve(v).then(function(v2) {
          resolve({ value: v2, done: d });
        }, reject);
      }
    };
    __makeTemplateObject = function(cooked, raw) {
      if (Object.defineProperty) {
        Object.defineProperty(cooked, "raw", { value: raw });
      } else {
        cooked.raw = raw;
      }
      return cooked;
    };
    var __setModuleDefault = Object.create ? function(o, v) {
      Object.defineProperty(o, "default", { enumerable: true, value: v });
    } : function(o, v) {
      o["default"] = v;
    };
    __importStar = function(mod) {
      if (mod && mod.__esModule)
        return mod;
      var result = {};
      if (mod != null) {
        for (var k in mod)
          if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
            __createBinding(result, mod, k);
      }
      __setModuleDefault(result, mod);
      return result;
    };
    __importDefault = function(mod) {
      return mod && mod.__esModule ? mod : { default: mod };
    };
    __classPrivateFieldGet = function(receiver, state, kind, f) {
      if (kind === "a" && !f)
        throw new TypeError("Private accessor was defined without a getter");
      if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
        throw new TypeError("Cannot read private member from an object whose class did not declare it");
      return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    };
    __classPrivateFieldSet = function(receiver, state, value, kind, f) {
      if (kind === "m")
        throw new TypeError("Private method is not writable");
      if (kind === "a" && !f)
        throw new TypeError("Private accessor was defined without a setter");
      if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
        throw new TypeError("Cannot write private member to an object whose class did not declare it");
      return kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value), value;
    };
    __classPrivateFieldIn = function(state, receiver) {
      if (receiver === null || typeof receiver !== "object" && typeof receiver !== "function")
        throw new TypeError("Cannot use 'in' operator on non-object");
      return typeof state === "function" ? receiver === state : state.has(receiver);
    };
    __addDisposableResource = function(env, value, async) {
      if (value !== null && value !== undefined) {
        if (typeof value !== "object" && typeof value !== "function")
          throw new TypeError("Object expected.");
        var dispose;
        if (async) {
          if (!Symbol.asyncDispose)
            throw new TypeError("Symbol.asyncDispose is not defined.");
          dispose = value[Symbol.asyncDispose];
        }
        if (dispose === undefined) {
          if (!Symbol.dispose)
            throw new TypeError("Symbol.dispose is not defined.");
          dispose = value[Symbol.dispose];
        }
        if (typeof dispose !== "function")
          throw new TypeError("Object not disposable.");
        env.stack.push({ value, dispose, async });
      } else if (async) {
        env.stack.push({ async: true });
      }
      return value;
    };
    var _SuppressedError = typeof SuppressedError === "function" ? SuppressedError : function(error, suppressed, message) {
      var e = new Error(message);
      return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
    };
    __disposeResources = function(env) {
      function fail(e) {
        env.error = env.hasError ? new _SuppressedError(e, env.error, "An error was suppressed during disposal.") : e;
        env.hasError = true;
      }
      function next() {
        while (env.stack.length) {
          var rec = env.stack.pop();
          try {
            var result = rec.dispose && rec.dispose.call(rec.value);
            if (rec.async)
              return Promise.resolve(result).then(next, function(e) {
                fail(e);
                return next();
              });
          } catch (e) {
            fail(e);
          }
        }
        if (env.hasError)
          throw env.error;
      }
      return next();
    };
    exporter("__extends", __extends);
    exporter("__assign", __assign);
    exporter("__rest", __rest);
    exporter("__decorate", __decorate);
    exporter("__param", __param);
    exporter("__esDecorate", __esDecorate);
    exporter("__runInitializers", __runInitializers);
    exporter("__propKey", __propKey);
    exporter("__setFunctionName", __setFunctionName);
    exporter("__metadata", __metadata);
    exporter("__awaiter", __awaiter);
    exporter("__generator", __generator);
    exporter("__exportStar", __exportStar);
    exporter("__createBinding", __createBinding);
    exporter("__values", __values);
    exporter("__read", __read);
    exporter("__spread", __spread);
    exporter("__spreadArrays", __spreadArrays);
    exporter("__spreadArray", __spreadArray);
    exporter("__await", __await);
    exporter("__asyncGenerator", __asyncGenerator);
    exporter("__asyncDelegator", __asyncDelegator);
    exporter("__asyncValues", __asyncValues);
    exporter("__makeTemplateObject", __makeTemplateObject);
    exporter("__importStar", __importStar);
    exporter("__importDefault", __importDefault);
    exporter("__classPrivateFieldGet", __classPrivateFieldGet);
    exporter("__classPrivateFieldSet", __classPrivateFieldSet);
    exporter("__classPrivateFieldIn", __classPrivateFieldIn);
    exporter("__addDisposableResource", __addDisposableResource);
    exporter("__disposeResources", __disposeResources);
  });
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/json-pack/lib/JsonPackExtension.js
var require_JsonPackExtension = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.JsonPackExtension = undefined;

  class JsonPackExtension {
    constructor(tag, val) {
      this.tag = tag;
      this.val = val;
    }
  }
  exports.JsonPackExtension = JsonPackExtension;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/decodeAscii.js
var require_decodeAscii = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.decodeAsciiMax15 = exports.decodeAscii = undefined;
  var fromCharCode = String.fromCharCode;
  var decodeAscii = (src, position, length) => {
    const bytes = [];
    for (let i = 0;i < length; i++) {
      const byte = src[position++];
      if (byte & 128)
        return;
      bytes.push(byte);
    }
    return fromCharCode.apply(String, bytes);
  };
  exports.decodeAscii = decodeAscii;
  var decodeAsciiMax15 = (src, position, length) => {
    if (length < 4) {
      if (length < 2) {
        if (length === 0)
          return "";
        else {
          const a = src[position++];
          if ((a & 128) > 1) {
            position -= 1;
            return;
          }
          return fromCharCode(a);
        }
      } else {
        const a = src[position++];
        const b = src[position++];
        if ((a & 128) > 0 || (b & 128) > 0) {
          position -= 2;
          return;
        }
        if (length < 3)
          return fromCharCode(a, b);
        const c = src[position++];
        if ((c & 128) > 0) {
          position -= 3;
          return;
        }
        return fromCharCode(a, b, c);
      }
    } else {
      const a = src[position++];
      const b = src[position++];
      const c = src[position++];
      const d = src[position++];
      if ((a & 128) > 0 || (b & 128) > 0 || (c & 128) > 0 || (d & 128) > 0) {
        position -= 4;
        return;
      }
      if (length < 6) {
        if (length === 4)
          return fromCharCode(a, b, c, d);
        else {
          const e = src[position++];
          if ((e & 128) > 0) {
            position -= 5;
            return;
          }
          return fromCharCode(a, b, c, d, e);
        }
      } else if (length < 8) {
        const e = src[position++];
        const f = src[position++];
        if ((e & 128) > 0 || (f & 128) > 0) {
          position -= 6;
          return;
        }
        if (length < 7)
          return fromCharCode(a, b, c, d, e, f);
        const g = src[position++];
        if ((g & 128) > 0) {
          position -= 7;
          return;
        }
        return fromCharCode(a, b, c, d, e, f, g);
      } else {
        const e = src[position++];
        const f = src[position++];
        const g = src[position++];
        const h = src[position++];
        if ((e & 128) > 0 || (f & 128) > 0 || (g & 128) > 0 || (h & 128) > 0) {
          position -= 8;
          return;
        }
        if (length < 10) {
          if (length === 8)
            return fromCharCode(a, b, c, d, e, f, g, h);
          else {
            const i = src[position++];
            if ((i & 128) > 0) {
              position -= 9;
              return;
            }
            return fromCharCode(a, b, c, d, e, f, g, h, i);
          }
        } else if (length < 12) {
          const i = src[position++];
          const j = src[position++];
          if ((i & 128) > 0 || (j & 128) > 0) {
            position -= 10;
            return;
          }
          if (length < 11)
            return fromCharCode(a, b, c, d, e, f, g, h, i, j);
          const k = src[position++];
          if ((k & 128) > 0) {
            position -= 11;
            return;
          }
          return fromCharCode(a, b, c, d, e, f, g, h, i, j, k);
        } else {
          const i = src[position++];
          const j = src[position++];
          const k = src[position++];
          const l = src[position++];
          if ((i & 128) > 0 || (j & 128) > 0 || (k & 128) > 0 || (l & 128) > 0) {
            position -= 12;
            return;
          }
          if (length < 14) {
            if (length === 12)
              return fromCharCode(a, b, c, d, e, f, g, h, i, j, k, l);
            else {
              const m = src[position++];
              if ((m & 128) > 0) {
                position -= 13;
                return;
              }
              return fromCharCode(a, b, c, d, e, f, g, h, i, j, k, l, m);
            }
          } else {
            const m = src[position++];
            const n = src[position++];
            if ((m & 128) > 0 || (n & 128) > 0) {
              position -= 14;
              return;
            }
            if (length < 15)
              return fromCharCode(a, b, c, d, e, f, g, h, i, j, k, l, m, n);
            const o = src[position++];
            if ((o & 128) > 0) {
              position -= 15;
              return;
            }
            return fromCharCode(a, b, c, d, e, f, g, h, i, j, k, l, m, n, o);
          }
        }
      }
    }
  };
  exports.decodeAsciiMax15 = decodeAsciiMax15;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/decodeUtf8/v18.js
var require_v18 = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  var fromCharCode = String.fromCharCode;
  exports.default = (buf, start, length) => {
    let offset = start;
    const end = offset + length;
    const points = [];
    while (offset < end) {
      let code = buf[offset++];
      if ((code & 128) !== 0) {
        const octet2 = buf[offset++] & 63;
        if ((code & 224) === 192) {
          code = (code & 31) << 6 | octet2;
        } else {
          const octet3 = buf[offset++] & 63;
          if ((code & 240) === 224) {
            code = (code & 31) << 12 | octet2 << 6 | octet3;
          } else {
            if ((code & 248) === 240) {
              const octet4 = buf[offset++] & 63;
              let unit = (code & 7) << 18 | octet2 << 12 | octet3 << 6 | octet4;
              if (unit > 65535) {
                unit -= 65536;
                const unit0 = unit >>> 10 & 1023 | 55296;
                code = 56320 | unit & 1023;
                points.push(unit0);
              } else {
                code = unit;
              }
            }
          }
        }
      }
      points.push(code);
    }
    return fromCharCode.apply(String, points);
  };
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/decodeUtf8/v16.js
var require_v16 = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  var tslib_1 = require_tslib();
  var decodeAscii_1 = require_decodeAscii();
  var v18_1 = tslib_1.__importDefault(require_v18());
  var hasBuffer = typeof Buffer !== "undefined";
  var utf8Slice = hasBuffer ? Buffer.prototype.utf8Slice : null;
  var from = hasBuffer ? Buffer.from : null;
  var shortDecoder = (buf, start, length) => (0, decodeAscii_1.decodeAsciiMax15)(buf, start, length) ?? (0, v18_1.default)(buf, start, length);
  var midDecoder = (buf, start, length) => (0, decodeAscii_1.decodeAscii)(buf, start, length) ?? (0, v18_1.default)(buf, start, length);
  var longDecoder = utf8Slice ? (buf, start, length) => utf8Slice.call(buf, start, start + length) : from ? (buf, start, length) => from(buf).subarray(start, start + length).toString("utf8") : v18_1.default;
  var decoder = (buf, start, length) => {
    if (length < 16)
      return shortDecoder(buf, start, length);
    if (length < 32)
      return midDecoder(buf, start, length);
    return longDecoder(buf, start, length);
  };
  exports.default = decoder;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/decodeUtf8/index.js
var require_decodeUtf8 = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.decodeUtf8 = undefined;
  var tslib_1 = require_tslib();
  var v16_1 = tslib_1.__importDefault(require_v16());
  exports.decodeUtf8 = v16_1.default;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/Reader.js
var require_Reader = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.Reader = undefined;
  var decodeUtf8_1 = require_decodeUtf8();

  class Reader {
    constructor() {
      this.uint8 = new Uint8Array([]);
      this.view = new DataView(this.uint8.buffer);
      this.x = 0;
    }
    reset(uint8) {
      this.x = 0;
      this.uint8 = uint8;
      this.view = new DataView(uint8.buffer, uint8.byteOffset, uint8.length);
    }
    peak() {
      return this.view.getUint8(this.x);
    }
    skip(length) {
      this.x += length;
    }
    buf(size) {
      const end = this.x + size;
      const bin = this.uint8.subarray(this.x, end);
      this.x = end;
      return bin;
    }
    u8() {
      return this.uint8[this.x++];
    }
    i8() {
      return this.view.getInt8(this.x++);
    }
    u16() {
      let x = this.x;
      const num = (this.uint8[x++] << 8) + this.uint8[x++];
      this.x = x;
      return num;
    }
    i16() {
      const num = this.view.getInt16(this.x);
      this.x += 2;
      return num;
    }
    u32() {
      const num = this.view.getUint32(this.x);
      this.x += 4;
      return num;
    }
    i32() {
      const num = this.view.getInt32(this.x);
      this.x += 4;
      return num;
    }
    u64() {
      const num = this.view.getBigUint64(this.x);
      this.x += 8;
      return num;
    }
    i64() {
      const num = this.view.getBigInt64(this.x);
      this.x += 8;
      return num;
    }
    f32() {
      const pos = this.x;
      this.x += 4;
      return this.view.getFloat32(pos);
    }
    f64() {
      const pos = this.x;
      this.x += 8;
      return this.view.getFloat64(pos);
    }
    utf8(size) {
      const start = this.x;
      this.x += size;
      return (0, decodeUtf8_1.decodeUtf8)(this.uint8, start, size);
    }
    ascii(length) {
      const uint8 = this.uint8;
      let str = "";
      const end = this.x + length;
      for (let i = this.x;i < end; i++)
        str += String.fromCharCode(uint8[i]);
      this.x = end;
      return str;
    }
  }
  exports.Reader = Reader;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/decodeUtf8/v10.js
var require_v10 = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  var fromCharCode = String.fromCharCode;
  exports.default = (buf, start, length) => {
    let offset = start;
    const end = offset + length;
    let str = "";
    while (offset < end) {
      const octet1 = buf[offset++];
      if ((octet1 & 128) === 0) {
        str += fromCharCode(octet1);
        continue;
      }
      const octet2 = buf[offset++] & 63;
      if ((octet1 & 224) === 192) {
        str += fromCharCode((octet1 & 31) << 6 | octet2);
        continue;
      }
      const octet3 = buf[offset++] & 63;
      if ((octet1 & 240) === 224) {
        str += fromCharCode((octet1 & 31) << 12 | octet2 << 6 | octet3);
        continue;
      }
      if ((octet1 & 248) === 240) {
        const octet4 = buf[offset++] & 63;
        let unit = (octet1 & 7) << 18 | octet2 << 12 | octet3 << 6 | octet4;
        if (unit > 65535) {
          unit -= 65536;
          const unit0 = unit >>> 10 & 1023 | 55296;
          unit = 56320 | unit & 1023;
          str += fromCharCode(unit0, unit);
        } else {
          str += fromCharCode(unit);
        }
      } else {
        str += fromCharCode(octet1);
      }
    }
    return str;
  };
});

// /Users/jpsilva/Projects/integro/node_modules/hyperdyperid/lib/randomU32.js
var require_randomU32 = __commonJS((exports) => {
  var randomU32 = function(min, max) {
    x ^= x << 13;
    x ^= x >>> 17;
    x ^= x << 5;
    return (x >>> 0) % (max - min + 1) + min;
  };
  var x = 1 + Math.round(Math.random() * ((-1 >>> 0) - 1));
  exports.randomU32 = randomU32;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/CachedUtf8Decoder.js
var require_CachedUtf8Decoder = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.CachedUtf8Decoder = undefined;
  var tslib_1 = require_tslib();
  var v10_1 = tslib_1.__importDefault(require_v10());
  var randomU32_1 = require_randomU32();

  class CacheItem {
    constructor(bytes, value) {
      this.bytes = bytes;
      this.value = value;
    }
  }

  class CachedUtf8Decoder {
    constructor() {
      this.caches = [];
      for (let i = 0;i < 31; i++)
        this.caches.push([]);
    }
    get(bytes, offset, size) {
      const records = this.caches[size - 1];
      const len = records.length;
      FIND_CHUNK:
        for (let i = 0;i < len; i++) {
          const record = records[i];
          const recordBytes = record.bytes;
          for (let j = 0;j < size; j++)
            if (recordBytes[j] !== bytes[offset + j])
              continue FIND_CHUNK;
          return record.value;
        }
      return null;
    }
    store(bytes, value) {
      const records = this.caches[bytes.length - 1];
      const record = new CacheItem(bytes, value);
      const length = records.length;
      if (length >= 16)
        records[(0, randomU32_1.randomU32)(0, 16 - 1)] = record;
      else
        records.push(record);
    }
    decode(bytes, offset, size) {
      if (!size)
        return "";
      const cachedValue = this.get(bytes, offset, size);
      if (cachedValue !== null)
        return cachedValue;
      const value = (0, v10_1.default)(bytes, offset, size);
      const copy = Uint8Array.prototype.slice.call(bytes, offset, offset + size);
      this.store(copy, value);
      return value;
    }
  }
  exports.CachedUtf8Decoder = CachedUtf8Decoder;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/util/lib/buffers/utf8/sharedCachedUtf8Decoder.js
var require_sharedCachedUtf8Decoder = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  var CachedUtf8Decoder_1 = require_CachedUtf8Decoder();
  exports.default = new CachedUtf8Decoder_1.CachedUtf8Decoder;
});

// /Users/jpsilva/Projects/integro/node_modules/@jsonjoy.com/json-pack/lib/msgpack/MsgPackDecoderFast.js
var require_MsgPackDecoderFast = __commonJS((exports) => {
  Object.defineProperty(exports, "__esModule", { value: true });
  exports.MsgPackDecoderFast = undefined;
  var tslib_1 = require_tslib();
  var JsonPackExtension_1 = require_JsonPackExtension();
  var Reader_1 = require_Reader();
  var sharedCachedUtf8Decoder_1 = tslib_1.__importDefault(require_sharedCachedUtf8Decoder());

  class MsgPackDecoderFast {
    constructor(reader = new Reader_1.Reader, keyDecoder = sharedCachedUtf8Decoder_1.default) {
      this.reader = reader;
      this.keyDecoder = keyDecoder;
    }
    decode(uint8) {
      this.reader.reset(uint8);
      return this.val();
    }
    read(uint8) {
      this.reader.reset(uint8);
      return this.val();
    }
    val() {
      const reader = this.reader;
      const byte = reader.u8();
      if (byte >= 224)
        return byte - 256;
      if (byte <= 191) {
        if (byte < 144) {
          if (byte <= 127)
            return byte;
          return this.obj(byte & 15);
        } else {
          if (byte < 160)
            return this.arr(byte & 15);
          else
            return reader.utf8(byte & 31);
        }
      }
      if (byte <= 208) {
        if (byte <= 200) {
          if (byte <= 196) {
            if (byte <= 194)
              return byte === 194 ? false : byte === 192 ? null : undefined;
            else
              return byte === 196 ? reader.buf(reader.u8()) : true;
          } else {
            if (byte <= 198)
              return byte === 198 ? reader.buf(reader.u32()) : reader.buf(reader.u16());
            else
              return byte === 200 ? this.ext(reader.u16()) : this.ext(reader.u8());
          }
        } else {
          return byte <= 204 ? byte <= 202 ? byte === 202 ? reader.f32() : this.ext(reader.u32()) : byte === 204 ? reader.u8() : reader.f64() : byte <= 206 ? byte === 206 ? reader.u32() : reader.u16() : byte === 208 ? reader.i8() : reader.u32() * 4294967296 + reader.u32();
        }
      } else if (byte <= 216) {
        return byte <= 212 ? byte <= 210 ? byte === 210 ? reader.i32() : reader.i16() : byte === 212 ? this.ext(1) : reader.i32() * 4294967296 + reader.u32() : byte <= 214 ? byte === 214 ? this.ext(4) : this.ext(2) : byte === 216 ? this.ext(16) : this.ext(8);
      } else {
        switch (byte) {
          case 217:
            return reader.utf8(reader.u8());
          case 218:
            return reader.utf8(reader.u16());
          case 219:
            return reader.utf8(reader.u32());
          case 220:
            return this.arr(reader.u16());
          case 221:
            return this.arr(reader.u32());
          case 222:
            return this.obj(reader.u16());
          case 223:
            return this.obj(reader.u32());
        }
      }
      return;
    }
    str() {
      const reader = this.reader;
      const byte = reader.u8();
      if (byte >> 5 === 5)
        return reader.utf8(byte & 31);
      switch (byte) {
        case 217:
          return reader.utf8(reader.u8());
        case 218:
          return reader.utf8(reader.u16());
        case 219:
          return reader.utf8(reader.u32());
      }
      return;
    }
    obj(size) {
      const obj = {};
      for (let i = 0;i < size; i++) {
        const key = this.key();
        if (key === "__proto__")
          throw 6;
        obj[key] = this.val();
      }
      return obj;
    }
    key() {
      const reader = this.reader;
      const byte = reader.view.getUint8(reader.x);
      if (byte >= 160 && byte <= 191) {
        const size = byte & 31;
        const key = this.keyDecoder.decode(reader.uint8, reader.x + 1, size);
        reader.x += 1 + size;
        return key;
      } else if (byte === 217) {
        const size = reader.view.getUint8(reader.x + 1);
        if (size < 32) {
          const key = this.keyDecoder.decode(reader.uint8, reader.x + 2, size);
          reader.x += 2 + size;
          return key;
        }
      }
      reader.x++;
      switch (byte) {
        case 217:
          return reader.utf8(reader.u8());
        case 218:
          return reader.utf8(reader.u16());
        case 219:
          return reader.utf8(reader.u32());
        default:
          return "";
      }
    }
    arr(size) {
      const arr = [];
      for (let i = 0;i < size; i++)
        arr.push(this.val());
      return arr;
    }
    ext(size) {
      const reader = this.reader;
      const type = reader.u8();
      const end = reader.x + size;
      const buf = reader.uint8.subarray(reader.x, end);
      reader.x = end;
      return new JsonPackExtension_1.JsonPackExtension(type, buf);
    }
    back(bytes) {
      this.reader.x -= bytes;
    }
  }
  exports.MsgPackDecoderFast = MsgPackDecoderFast;
});

// src/integro.ts
var MsgPackEncoderFast = __toESM(require_MsgPackEncoderFast(), 1);
var MsgPackDecoderFast = __toESM(require_MsgPackDecoderFast(), 1);
import {ServerResponse} from "node:http";

// src/respondWith.ts
var hasResponseInit = Symbol("hasResponseInit");
var respondWith = (data, responseInit) => ({
  [hasResponseInit]: true,
  data,
  responseInit
});
var isResponseInitObject = (object) => typeof object === "object" && object !== null && object[hasResponseInit] === true;

// src/integro.ts
class PathError extends Error {
  constructor() {
    super(...arguments);
  }
}
var encoder = new MsgPackEncoderFast.MsgPackEncoderFast;
var decoder = new MsgPackDecoderFast.MsgPackDecoderFast;
var accessHeaders = {
  "Access-Control-Allow-Methods": "OPTIONS, POST"
};
var parseIncomingMessageUrl = (req) => {
  let protocol = req.socket.encrypted ? "https" : "http";
  const baseUrl = `${protocol}://${req.headers.host}`;
  if (!req.url) {
    return new URL(baseUrl);
  }
  const parsedUrl = new URL(req.url, `${protocol}://${req.headers.host}`);
  return parsedUrl;
};
var getData = async (req) => {
  const arrayBuffer = await req.arrayBuffer();
  const buffer = Buffer.from(arrayBuffer);
  const data = decoder.read(buffer);
  if (!Array.isArray(data.path) || typeof data.path[0] !== "string" || !Array.isArray(data.args)) {
    throw new Error("Data is malformed");
  }
  return data;
};
var resolveProp = async ({ path: [firstProp, ...path], app, request }) => {
  const property = app && (typeof app === "object" ? app[firstProp] : undefined);
  if (!property)
    throw new PathError;
  const unwrappedProperty = isUnwrappable(property) ? await property(request) : property;
  return path.length ? resolveProp({ path, app: unwrappedProperty, request }) : unwrappedProperty;
};
var getHttpMessageBody = (incomingMessage) => new Promise((resolve) => {
  const body = [];
  incomingMessage.on("data", (chunk) => body.push(chunk));
  incomingMessage.on("end", () => resolve(new Blob(body)));
});
var toRequest = async (incomingMessage) => new Request(parseIncomingMessageUrl(incomingMessage), {
  method: incomingMessage.method,
  headers: incomingMessage.headers,
  body: await getHttpMessageBody(incomingMessage)
});
var handleRequest = async (app, request) => {
  try {
    const data = await getData(request);
    const { args, path } = data;
    try {
      const handler = await resolveProp({ path, app, request });
      if (typeof handler !== "function") {
        throw new PathError("handler is not a function");
      }
      const res = await handler(...args);
      if (isResponseInitObject(res)) {
        return new Response(encoder.encode(res.data), res.responseInit);
      }
      return new Response(encoder.encode(res));
    } catch (e) {
      if (e instanceof PathError) {
        return new Response(encoder.encode(`Path "${path.join(".")}" could not be found in the app.`), { status: 404 });
      }
      if (e instanceof Error) {
        return new Response(encoder.encode(e.message), { status: 404 });
      }
      return new Response(encoder.encode("Something went wrong."), { status: 400 });
    }
  } catch (e) {
    return new Response(encoder.encode("Could not parse body."), { status: 400 });
  }
};
var integro = (app) => async (request, response) => {
  const usesServerResponse = response instanceof ServerResponse;
  const req = request instanceof Request ? request : await toRequest(request);
  try {
    if (req.method === "OPTIONS") {
      if (usesServerResponse) {
        response.writeHead(204, accessHeaders);
        response.end();
      }
      return new Response(undefined, { headers: accessHeaders, status: 204 });
    }
    const res = await handleRequest(app, req);
    if (usesServerResponse) {
      response.statusCode = res.status;
      response.statusMessage = res.statusText;
      res.headers.forEach((value, key) => response.setHeader(key, value));
      response.end(Buffer.from(await (await res.blob()).arrayBuffer()));
    }
    return res;
  } catch (e) {
    if (usesServerResponse) {
      response.statusCode = 403;
      response.end(encoder.encode(e instanceof Error ? e.message : "An error occured"));
    }
    return new Response(encoder.encode(e instanceof Error ? e.message : "An error occured"), { status: 403 });
  }
};
// src/defineApp.ts
var defineApp = (app) => app;
// src/unwrap.ts
var canUnwrappable = Symbol("canUnwrappable");
var unwrap = (handler) => {
  const fn = (request) => handler(request);
  fn[canUnwrappable] = true;
  return fn;
};
var isUnwrappable = (fn) => typeof fn === "function" && fn[canUnwrappable] === true;
// src/createClient.ts
var MsgPackDecoderFast3 = __toESM(require_MsgPackDecoderFast(), 1);
var MsgPackEncoderFast3 = __toESM(require_MsgPackEncoderFast(), 1);

// src/utils/createProxy.ts
var createProxy = (apply, path = []) => new Proxy(() => {
}, {
  get: (_target, key) => key === Symbol.toStringTag ? path.join(".") : createProxy(apply, [...path, key.toString()]),
  apply: (_target, _thisArg, args) => apply(path, args)
});

// src/createClient.ts
var encoder2 = new MsgPackEncoderFast3.MsgPackEncoderFast;
var decoder2 = new MsgPackDecoderFast3.MsgPackDecoderFast;
var post = async ({
  url,
  requestInit = {},
  data
}) => {
  const init = typeof requestInit === "function" ? requestInit() : requestInit;
  const res = await fetch(url, {
    method: "POST",
    ...init,
    headers: {
      "Content-Type": "application/msgpack",
      ...init.headers
    },
    body: encoder2.encode(data)
  });
  const arrayBuffer = await res.arrayBuffer();
  const unpacked = decoder2.read(new Uint8Array(arrayBuffer));
  if (!res.ok) {
    throw new Error("The server responded in error.", {
      cause: unpacked
    });
  }
  return unpacked;
};
var createClient = (url = "/", { requestInit } = {}) => createProxy((path, args) => post({
  url,
  requestInit,
  data: {
    path,
    args
  }
}));
export {
  unwrap,
  respondWith,
  isUnwrappable,
  isResponseInitObject,
  integro,
  defineApp,
  createClient
};
